@@ -1,9 +1,13 @@
 from ._common import *
+"""Should mostly use class from now on and use these functions as the 'backend'"""
 
 # Latest Rates
 FOREX_LATEST_URL = prepend_iex_url('fx') + 'latest?'
 def forex_latest_rate(symbols, vprint=False):
-    """Returns the latest exchange rate for the requested currency pair.
+    """:return: Latest FOREX rate for the requested currency pair symbol.
+
+    :param symbol: The symbol of the currency pair you would like to return.
+    :type symbol: string, required
     """
     url = FOREX_LATEST_URL + f'symbols={symbols}'
     return get_iex_json_request(url, vprint=vprint)
@@ -12,7 +16,12 @@ def forex_latest_rate(symbols, vprint=False):
 # Currency Conversion
 FOREX_CONVERSION_URL = prepend_iex_url('fx') + 'convert?'
 def forex_conversion(symbols, amount, vprint=False):
-    """Returns a converted value according to the requested currency pair.
+    """:return: Converts one currency to another using up-to-date currency information.
+
+    :param symbol: The symbol of the currency pair you would like to return.
+    :type symbol: string, required
+    :param amount: The amount of the primary currency you wish to calculate and exchange rate on.
+    :type amount: float, required
     """
     url = FOREX_CONVERSION_URL + f'symbols={symbols}&amount={amount}'
     return get_iex_json_request(url, vprint=vprint)
@@ -21,7 +30,10 @@ def forex_conversion(symbols, amount, vprint=False):
 # Historical Data
 FOREX_HISTORICAL_URL = prepend_iex_url('fx') + 'historical?'
 def forex_historical(symbols, vprint=False, **queries):
-    """Returns a list of the historical exchange rates for the requested currency pair.
+    """:return: Historical FOREX rates for the requested currency pair symbol.
+
+    :param symbol: The symbol of the currency pair you would like to return.
+    :type symbol: string, required
     """
     url = FOREX_HISTORICAL_URL + f'symbols={symbols}'
     for key, value in queries.items():
